/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package dao;

import conexao.ConnectionFactory;
import java.io.Serializable;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;
import modelos.Exame;
import modelos.Instituicao;
import modelos.Paciente;
import modelos.Projeto;
import modelos.TipoUsuario;
import modelos.Usuario;

/**
 *
 * @author DanielDruszcz
 */
public class ExameDAO implements Serializable {

    //fazer um insert onde o nome da imagem seja adicionado do id que sera setado no banco

    public Exame cadastra(Exame exame) {
        String sql = "INSERT INTO exame (usuario_upload , projeto , data_envio , paciente , quantidade_imagens,"
                + "local_exame, nome, dataexame, anon, modalidade) VALUES (? , ? , ? , ? , ?, ?, ?, ?, ?, ?)";
        try (Connection con = new ConnectionFactory().getConnection()) {
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql, Statement.RETURN_GENERATED_KEYS)) {
                java.sql.Timestamp timestamp = new java.sql.Timestamp(exame.getDataDeEnvio().getTime());
                stmt.setLong(1, exame.getUsuarioUpload().getId());
                stmt.setLong(2, exame.getProjeto().getId());
                stmt.setTimestamp(3, timestamp);
                stmt.setLong(4, exame.getPaciente().getId());
                stmt.setInt(5, exame.getQuantidade());
                stmt.setString(6, exame.getLocal());
                stmt.setString(7, exame.getNome());
                if (exame.getDataDoExame() != null) {
                    stmt.setDate(8, new java.sql.Date(exame.getDataDoExame().getTime()));
                } else {
                    stmt.setDate(8, null);
                }
                stmt.setBoolean(9, exame.isAnon());
                stmt.setString(10, exame.getModalidade());
                stmt.execute();
                try (ResultSet rs = stmt.getGeneratedKeys()) {
                    if (rs.next()) {
                        exame.setId(rs.getInt("id"));
                        con.commit();
                        return exame;
                    }
                    throw new RuntimeException();
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }

    public List<Exame> listaExamesProjeto(Projeto projeto) {
        String sql = "SELECT exame.id, exame.nome, exame.usuario_upload, exame.modalidade, "
                + "exame.local_exame, exame.projeto, exame.dataexame, exame.data_envio, exame.paciente "
                + "FROM exame "
                + "WHERE exame.projeto = ?";
        try (Connection con = new ConnectionFactory().getConnection()) {
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)) {
                stmt.setLong(1, projeto.getId());
                try (ResultSet rs = stmt.executeQuery()) {
                    List<Exame> lista = new ArrayList<>();
                    while (rs.next()) {
                        Exame exame = new Exame();
                        exame.setId(rs.getInt("id"));
                        exame.setNome(rs.getString("nome"));
                        exame.setUsuarioUpload(pegaUUpload(new Usuario(rs.getLong("usuario_upload")) , con));
                        exame.setProjeto(projeto);
                        exame.setPaciente(pegaPaUpload(new Paciente(rs.getLong("paciente")) , con));
                        exame.setModalidade(rs.getString("modalidade"));
                        exame.setLocal(rs.getString("local_exame"));
                        exame.setDataDoExame(rs.getDate("dataexame"));
                        exame.setDataDeEnvio(rs.getTimestamp("data_envio"));
                        
                        lista.add(exame);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
           } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        }
    
     public List<Exame> listaExamesUsuarios(Usuario usuario) {
        String sql = "SELECT exame.id, exame.nome, exame.usuario_upload, exame.modalidade, "
                + "exame.local_exame, exame.projeto, exame.dataexame, exame.data_envio, exame.paciente "
                + "FROM exame "
                + "WHERE exame.usuario_upload = ?";
        try (Connection con = new ConnectionFactory().getConnection()) {
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)) {
                stmt.setLong(1, usuario.getId());
                try (ResultSet rs = stmt.executeQuery()) {
                    List<Exame> lista = new ArrayList<>();
                    while (rs.next()) {
                        Exame exame = new Exame();
                        exame.setId(rs.getInt("id"));
                        exame.setNome(rs.getString("nome"));
                        exame.setUsuarioUpload(usuario);
                        exame.setProjeto(pegaPUpload(new Projeto(rs.getLong("projeto")) , con));
                        exame.setPaciente(pegaPaUpload(new Paciente(rs.getLong("paciente")) , con));
                        exame.setModalidade(rs.getString("modalidade"));
                        exame.setLocal(rs.getString("local_exame"));
                        exame.setDataDoExame(rs.getDate("dataexame"));
                        exame.setDataDeEnvio(rs.getTimestamp("data_envio"));
                        
                        lista.add(exame);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
           } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        }
    
    private Usuario pegaUUpload(Usuario usuario , Connection con){
        String sql = "select u.nome , \n" +
                     "       u.sobrenome ,\n" +
                     "       u.email ,\n" +
                     "       u.ativo ,\n" +
                     "       tu.id ,\n" +
                     "       tu.tipo\n" +
                     "from usuario u\n" +
                     "     inner join tipo_usuario tu on tu.id = u.tipo\n" +
                     "where u.id = ?";
        try (PreparedStatement stmt = con.prepareStatement(sql)){
            stmt.setLong(1, usuario.getId());
            try (ResultSet rs = stmt.executeQuery()){
                if(rs.next()){
                    usuario.setNome(rs.getString("nome"));
                    usuario.setSobrenome(rs.getString("sobrenome"));
                    usuario.setEmail(rs.getString("email"));
                    TipoUsuario tipo = new TipoUsuario();
                    tipo.setId(rs.getLong("id"));
                    tipo.setTipo(rs.getString("tipo"));
                    usuario.setTipoUsuario(tipo);
                    return usuario;
                }
                throw new RuntimeException();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
    private Projeto pegaPUpload(Projeto projeto , Connection con){
        String sql = "select p.id , \n" +
                     "       p.nome ,\n" +
                     "       p.descricao \n" +
                     "from projeto p\n" +
                     "where p.id = ?";
        try (PreparedStatement stmt = con.prepareStatement(sql)){
            stmt.setLong(1, projeto.getId());
            try (ResultSet rs = stmt.executeQuery()){
                if(rs.next()){
                    projeto.setNome(rs.getString("nome"));
                    projeto.setDescricao(rs.getString("descricao"));
                    projeto.setId(rs.getLong("id"));
                    return projeto;
                }
                throw new RuntimeException();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
    private Paciente pegaPaUpload(Paciente paciente , Connection con){
        String sql = "select p.id , \n" +
                     "       p.data_nasc ,\n" +
                     "       p.idade ,\n" +
                     "       p.sexo \n" +
                     "from paciente p\n" +
                     "where p.id = ?";
        try (PreparedStatement stmt = con.prepareStatement(sql)){
            stmt.setLong(1, paciente.getId());
            try (ResultSet rs = stmt.executeQuery()){
                if(rs.next()){
                    paciente.setId(rs.getLong("id"));
                    paciente.setDataNasc(rs.getDate("data_nasc"));
                    paciente.setIdade(rs.getString("idade"));
                    paciente.setSexo(rs.getString("sexo"));
                    return paciente;
                }
                throw new RuntimeException();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }

    }
