/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package dao;

import conexao.ConnectionFactory;
import java.io.Serializable;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import modelos.Instituicao;
import modelos.Projeto;
import modelos.TipoProjeto;
import modelos.TipoUsuario;
import modelos.TipoVinculo;
import modelos.Usuario;

/**
 *
 * @author joaofelipelopes
 */
public class ProjetoDAO implements Serializable {
/* ------------------------------- CADASTRA --------------------------------- */
    
    public Projeto cadastra(Projeto projeto){
        String sql = "INSERT INTO projeto (nome , descricao , moderador, tipo) VALUES (? , ? , ?,0)";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql , Statement.RETURN_GENERATED_KEYS)){
                stmt.setString(1, projeto.getNome());
                stmt.setString(2, projeto.getDescricao());
                stmt.setLong(3, projeto.getModerador().getId());
                stmt.execute();
                try (ResultSet rs = stmt.getGeneratedKeys()){
                    if(rs.next()){
                        projeto.setId(rs.getLong("id"));
                        vinculaInstituicoes(con , projeto);
                        vinculaModerador(con, projeto);
                        con.commit();
                        return projeto;
                    }
                    throw new RuntimeException();
                } catch (Exception e) {
                    con.rollback();
                    e.printStackTrace();
                    throw new RuntimeException();
                    
                }
            } catch (Exception e) {
                con.rollback();
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
    public Projeto atualizaMod(Projeto projeto){
        String sql = "UPDATE projeto set moderador = ? where id = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql , Statement.RETURN_GENERATED_KEYS)){
                stmt.setLong(1, projeto.getModerador().getId());
                stmt.setLong(2, projeto.getId());
                stmt.execute();
                try (ResultSet rs = stmt.getGeneratedKeys()){
                    if(rs.next()){
                        projeto.setId(rs.getLong("id"));
                        con.commit();
                        return projeto;
                    }
                    throw new RuntimeException();
                } catch (Exception e) {
                    con.rollback();
                    e.printStackTrace();
                    throw new RuntimeException();
                    
                }
            } catch (Exception e) {
                con.rollback();
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* ------------------------- VINCULA INSTITUICOES --------------------------- */
    
    private void vinculaInstituicoes(Connection con , Projeto projeto){
        String sql = "INSERT INTO item_projeto_instituicao (id_projeto , id_instituicao) VALUES (? , ?)";
        for(Instituicao instituicao : projeto.getInstituicoes()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, projeto.getId());
                stmt.setLong(2, instituicao.getId());
                stmt.execute();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        }
    }
    
    private void vinculaModerador(Connection con , Projeto projeto){
        String sql = "INSERT INTO item_usuario_projeto (id_projeto , id_usuario, tipo) VALUES (? , ?, 1)";
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, projeto.getId());
                stmt.setLong(2, projeto.getModerador().getId());
                stmt.execute();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
    }
    
/* --------------------------------- PEGA ----------------------------------- */
    
    public Projeto pega(Projeto projeto){
        String sql = "SELECT nome , descricao , moderador , tipo FROM projeto WHERE id = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, projeto.getId());
                try (ResultSet rs = stmt.executeQuery()){
                    if(rs.next()){
                        Projeto projetoPego = new Projeto();
                        projetoPego.setId(projeto.getId());
                        projetoPego.setNome(rs.getString("nome"));
                        projeto.setDescricao(rs.getString("descricao"));
                        TipoProjeto tipoProjeto = new TipoProjeto();
                        tipoProjeto.setId(rs.getInt("tipo"));
                        projeto.setTipo(tipoProjeto);
                        projeto.setModerador(pegaModerador(new Usuario(rs.getLong("moderador")) , con));
                        return projeto;
                    }
                    throw new RuntimeException();
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }

/* --------------------------- PEGA MODERADOR ------------------------------- */
    
    private Usuario pegaModerador(Usuario usuario , Connection con){
        String sql = "select u.nome , \n" +
                     "       u.sobrenome ,\n" +
                     "       u.email ,\n" +
                     "       u.ativo ,\n" +
                     "       tu.id ,\n" +
                     "       tu.tipo\n" +
                     "from usuario u\n" +
                     "     inner join tipo_usuario tu on tu.id = u.tipo\n" +
                     "where u.id = ?";
        try (PreparedStatement stmt = con.prepareStatement(sql)){
            stmt.setLong(1, usuario.getId());
            try (ResultSet rs = stmt.executeQuery()){
                if(rs.next()){
                    usuario.setNome(rs.getString("nome"));
                    usuario.setSobrenome(rs.getString("sobrenome"));
                    usuario.setEmail(rs.getString("email"));
                    usuario.setAtivo(rs.getBoolean("ativo"));
                    TipoUsuario tipo = new TipoUsuario();
                    tipo.setId(rs.getLong("id"));
                    tipo.setTipo(rs.getString("tipo"));
                    usuario.setTipoUsuario(tipo);
                    return usuario;
                }
                throw new RuntimeException();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
     public List<Projeto> listaProjetosInvalidos(){
          String sql = "SELECT id, nome, descricao ,moderador FROM projeto where tipo = 0";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                try (ResultSet rs = stmt.executeQuery()){
                    List<Projeto> lista = new ArrayList<>();
                    while(rs.next()){
                        Projeto projeto = new Projeto();
                        projeto.setId((long)rs.getInt("id"));
                        projeto.setNome(rs.getString("nome"));
                        projeto.setDescricao(rs.getString("descricao"));
                        projeto.setModerador(pegaModerador(new Usuario(rs.getLong("moderador")) , con));
                        projeto.setInstituicoes(pegaInstituicoes(con, projeto));
                        lista.add(projeto);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
      public List<Projeto> listaProjetosValidos(Usuario usuario){
         List<Projeto> doUser = listaProjetosUsuario(usuario);
         String sql = "SELECT projeto.id, projeto.nome, projeto.descricao,projeto.moderador "
                 + "FROM projeto WHERE projeto.tipo = 1 and projeto.moderador != ? ";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, usuario.getId());
                try (ResultSet rs = stmt.executeQuery()){
                    List<Projeto> lista = new ArrayList<>();
                    while(rs.next()){
                        Projeto projeto = new Projeto();
                        projeto.setId((long)rs.getInt("id"));
                        projeto.setNome(rs.getString("nome"));
                        projeto.setDescricao(rs.getString("descricao"));
                        projeto.setModerador(pegaModerador(new Usuario(rs.getLong("moderador")) , con));
                        projeto.setInstituicoes(pegaInstituicoes(con, projeto));
                        if(doUser.contains(projeto)){
                           
                        }else{
                        lista.add(projeto);
                        }
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
      
      public List<Projeto> listaProjetosGerais(){
          //arrumar para trazer apenas projetos que o usuario nao tenha vinculo
         String sql = "SELECT projeto.id, projeto.nome, projeto.descricao,projeto.moderador, projeto.tipo "
                 + "FROM projeto "
                 + "where projeto.tipo = 1 or projeto.tipo = 3";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                try (ResultSet rs = stmt.executeQuery()){
                    List<Projeto> lista = new ArrayList<>();
                    while(rs.next()){
                        Projeto projeto = new Projeto();
                        projeto.setId((long)rs.getInt("id"));
                        projeto.setNome(rs.getString("nome"));
                        projeto.setDescricao(rs.getString("descricao"));
                        TipoProjeto tipoProjeto = new TipoProjeto();
                        tipoProjeto.setId(rs.getInt("tipo"));
                        if(rs.getInt("tipo") == 1){
                            projeto.setSituacao("Ativo");
                            projeto.setCor("green");
                            projeto.setMostra(true);
                        }else{
                            projeto.setSituacao("Inativo");
                            projeto.setCor("red");
                            projeto.setMostra(false);
                        }
                        projeto.setModerador(pegaModerador(new Usuario(rs.getLong("moderador")) , con));
                        projeto.setInstituicoes(pegaInstituicoes(con, projeto));
                        lista.add(projeto);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
      
      public List<Instituicao> pegaInstituicoes(Connection con , Projeto projeto){
        String sql = "SELECT instituicao.id, instituicao.nome FROM instituicao "
                + "inner join item_projeto_instituicao "
                + "on item_projeto_instituicao.id_instituicao = instituicao.id "
                + "WHERE item_projeto_instituicao.id_projeto = ?;";
        try (PreparedStatement stmt = con.prepareStatement(sql)){
            stmt.setLong(1, projeto.getId());
            try (ResultSet rs = stmt.executeQuery()){
                List<Instituicao> lista = new ArrayList<>();
                while(rs.next()){
                    Instituicao inst = new Instituicao();
                    inst.setId(rs.getInt("id"));
                    inst.setNome(rs.getString("nome"));
                    lista.add(inst);
                }
                return lista;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
      
      public List<Instituicao> pegaInstituicoes(Connection con , Usuario usuario){
         String sql = "SELECT instituicao.id, instituicao.nome FROM instituicao "
                + "inner join item_usuario_instituicao "
                + "on item_usuario_instituicao.id_instituicao = instituicao.id "
                + "WHERE item_usuario_instituicao.id_usuario = ?;";
        try (PreparedStatement stmt = con.prepareStatement(sql)){
            stmt.setLong(1, usuario.getId());
            try (ResultSet rs = stmt.executeQuery()){
                List<Instituicao> lista = new ArrayList<>();
                while(rs.next()){
                    Instituicao inst = new Instituicao();
                    inst.setId(rs.getInt("id"));
                    inst.setNome(rs.getString("nome"));
                    lista.add(inst);
                }
                return lista;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
      
       public Projeto ativa(Projeto projeto){
        String sql = "UPDATE projeto SET tipo = 1, data = ? WHERE id = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setDate(1 ,new java.sql.Date(new Date().getTime()));
                stmt.setLong(2, projeto.getId());
                stmt.execute();
                con.commit();
                return projeto;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
       
        public Projeto desativa(Projeto projeto){
        String sql = "UPDATE projeto SET tipo = 3 WHERE id = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, projeto.getId());
                stmt.execute();
                con.commit();
                return projeto;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
       
       public List<Usuario> listaSolicitacoes(Projeto projeto){
           String sql = "SELECT usuario.id, usuario.nome, usuario.sobrenome,usuario.email FROM usuario "
                   + "inner join item_usuario_projeto on usuario.id = item_usuario_projeto.id_usuario "
                   + "where item_usuario_projeto.id_projeto = ? and item_usuario_projeto.tipo = 0";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, projeto.getId());
                try (ResultSet rs = stmt.executeQuery()){
                    List<Usuario> lista = new ArrayList<>();
                    while(rs.next()){
                        Usuario user = new Usuario();
                        user.setId((long)rs.getInt("id"));
                        user.setNome(rs.getString("nome"));
                        user.setSobrenome(rs.getString("sobrenome"));
                        user.setEmail(rs.getString("email"));
                        user.setInstituicoes(pegaInstituicoes(con, user));
                        lista.add(user);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
       public List<Projeto> listaProjetosUsuario(Usuario usuario){
           String sql = "SELECT projeto.id, projeto.nome, projeto.descricao, projeto.moderador,"
                   + "projeto.tipo, item_usuario_projeto.tipo as tipo2 FROM projeto "
                   + "inner join item_usuario_projeto on projeto.id = item_usuario_projeto.id_projeto "
                   + "where item_usuario_projeto.id_usuario = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, usuario.getId());
                try (ResultSet rs = stmt.executeQuery()){
                    List<Projeto> lista = new ArrayList<>();
                    while(rs.next()){
                        Projeto proj = new Projeto();
                        proj.setId((long)rs.getInt("id"));
                        proj.setNome(rs.getString("nome"));
                        proj.setDescricao(rs.getString("descricao"));
                        TipoProjeto tipoProjeto = new TipoProjeto();
                        tipoProjeto.setId(rs.getInt("tipo"));
                        proj.setModerador(pegaModerador(new Usuario(rs.getLong("moderador")) , con));
                        TipoVinculo tipoVinculo = new TipoVinculo();
                        tipoVinculo.setId(rs.getInt("tipo2"));
                        if(proj.getModerador().getId() == usuario.getId()){
                            proj.setSituacaov("Moderador");
                            proj.setCorv("blue");
                        }else if(tipoVinculo.getId() == 1){
                            proj.setSituacaov("Participando");
                            proj.setCorv("green");
                        }else if(tipoVinculo.getId() == 0){
                            proj.setSituacaov("Pendente");
                            proj.setCorv("#EEEE00");
                        }else if(tipoVinculo.getId() == 3){
                            proj.setSituacaov("Reprovado");
                            proj.setCorv("red");
                        }
                     
                        if(tipoProjeto.getId() == 1){
                            proj.setSituacao("Aprovado");
                            proj.setCor("green");
                        }else if(tipoProjeto.getId() == 0){
                            proj.setSituacao("Pendente");
                             proj.setCor("#EEEE00");
                        }else if(tipoProjeto.getId() == 2){
                            proj.setSituacao("Reprovado");
                             proj.setCor("red");
                        }else if(tipoProjeto.getId() == 3){
                            proj.setSituacao("Inativo");
                            proj.setCor("orange");
                        }
                        if(tipoVinculo.getId() == 1 && tipoProjeto.getId() == 1
                                || proj.getModerador().getId() == usuario.getId()
                                && tipoProjeto.getId() == 1){
                            proj.setMostra(true);
                        }else{
                            proj.setMostra(false);
                        }
                        proj.setTipov(tipoVinculo);
                        proj.setTipo(tipoProjeto);
                        lista.add(proj);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
       
     
       
       public Usuario ativaVinculo(Usuario usuario, Projeto projeto){
        String sql = "UPDATE item_usuario_projeto SET tipo = 1, data_respota = ? WHERE id_usuario = ? "
                + "and id_projeto = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setDate(1, new java.sql.Date(new Date().getTime()));
                stmt.setLong(2, usuario.getId());
                stmt.setLong(3, projeto.getId());
                stmt.execute();
                con.commit();
                return usuario;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
       
       public List<Usuario> listaUsuariosProjeto(Projeto projeto){
           String sql = "SELECT usuario.id, usuario.nome, usuario.sobrenome,usuario.email, usuario.ativo FROM usuario "
                   + "inner join item_usuario_projeto on usuario.id = item_usuario_projeto.id_usuario "
                   + "where item_usuario_projeto.id_projeto = ? and item_usuario_projeto.tipo = 1"
                   + "and item_usuario_projeto.id_usuario != ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, projeto.getId());
                stmt.setLong(2, projeto.getModerador().getId());
                try (ResultSet rs = stmt.executeQuery()){
                    List<Usuario> lista = new ArrayList<>();
                    while(rs.next()){
                        Usuario user = new Usuario();
                        user.setId((long)rs.getInt("id"));
                        user.setNome(rs.getString("nome"));
                        user.setSobrenome(rs.getString("sobrenome"));
                        user.setEmail(rs.getString("email"));
                        user.setAtivo(rs.getBoolean("ativo"));
                        user.setInstituicoes(pegaInstituicoes(con, user));
                        lista.add(user);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
       //arrumar para update tipo 2
       public void remove(Projeto projeto){
        String sqlInstituicoes = "DELETE FROM item_projeto_instituicao WHERE id_projeto = ?";
        String sqlUsuario = "DELETE FROM projeto WHERE id = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sqlInstituicoes)){
                stmt.setLong(1, projeto.getId());
                stmt.execute();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
            try (PreparedStatement stmt = con.prepareStatement(sqlUsuario)){
                stmt.setLong(1, projeto.getId());
                stmt.execute();
                con.commit();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
        public void removeVinculo(Usuario usuario, Projeto projeto){
        String sql = "DELETE FROM item_usuario_projeto WHERE id_usuario = ? "
                + "and id_projeto = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, usuario.getId());
                stmt.setLong(2, projeto.getId());
                stmt.execute();
                con.commit();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
        
        
       public List<Projeto> consultaMod(Usuario usuario){
           String sql = "SELECT projeto.id, projeto.nome FROM projeto "
                   + "where projeto.moderador = ? and projeto.tipo = 1";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, usuario.getId());
                try (ResultSet rs = stmt.executeQuery()){
                    List<Projeto> lista = new ArrayList<>();
                    while(rs.next()){
                        Projeto proj = new Projeto();
                        proj.setId((long)rs.getInt("id"));
                        proj.setNome(rs.getString("nome"));
                        lista.add(proj);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
        public Projeto reprova(Projeto projeto){
        String sql = "UPDATE projeto set tipo = 2, data = ? where id = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql , Statement.RETURN_GENERATED_KEYS)){
                stmt.setDate(1, new java.sql.Date(new Date().getTime()));
                stmt.setLong(2, projeto.getId());
                stmt.execute();
                try (ResultSet rs = stmt.getGeneratedKeys()){
                    if(rs.next()){
                        projeto.setId(rs.getLong("id"));
                        con.commit();
                        return projeto;
                    }
                    throw new RuntimeException();
                } catch (Exception e) {
                    con.rollback();
                    e.printStackTrace();
                    throw new RuntimeException();
                    
                }
            } catch (Exception e) {
                con.rollback();
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
       
       public int contaUsers(Projeto projeto){
        String sql = "select count(*) from item_usuario_projeto where id_projeto = ? ";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, projeto.getId());
                try (ResultSet rs = stmt.executeQuery()){
                   if(rs.next()){
                       return rs.getInt("count");
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
        return 0;
     }
       
       public int contaExames(Projeto projeto){
        String sql = "select count(*) from exame where projeto = ? ";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, projeto.getId());
                try (ResultSet rs = stmt.executeQuery()){
                   if(rs.next()){
                       return rs.getInt("count");
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
        return 0;
       }
}
