/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package dao;

import conexao.ConnectionFactory;
import criptografia.MD5;
import java.io.Serializable;
import java.sql.Connection;
import java.sql.Date;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;
import modelos.Instituicao;
import modelos.Projeto;
import modelos.TipoUsuario;
import modelos.Usuario;

/**
 *
 * @author joaofelipelopes
 */
public class UsuarioDAO implements Serializable{
    
/* ----------------------------- CADASTRA ----------------------------------- */
    
    public Usuario cadastra(Usuario usuario){
        String sql = "INSERT INTO usuario (nome , sobrenome , email , senha , tipo) VALUES (? , ? , ? , ? , ?)";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql , Statement.RETURN_GENERATED_KEYS)){
                stmt.setString(1, usuario.getNome());
                stmt.setString(2, usuario.getSobrenome());
                stmt.setString(3, usuario.getEmail());
                stmt.setString(4, senhaCriptografada(usuario));
                stmt.setLong(5, usuario.getTipoUsuario().getId());
                stmt.execute();
                try (ResultSet rs = stmt.getGeneratedKeys()){
                    if(rs.next()){
                        usuario.setId(rs.getInt("id"));
                        cadastraInstituicoes(con, usuario.getInstituicoes(), usuario); // cadastra as instituicoes
                        con.commit();
                        return usuario;
                    }
                    throw new RuntimeException();
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* ------------------------- CADASTRA INSTITUICOES -------------------------- */
    
    private void cadastraInstituicoes(Connection con , List<Instituicao> instituicoes , Usuario usuario){
        String sql = "INSERT INTO item_usuario_instituicao (id_usuario , id_instituicao) VALUES (? , ?);";
        for(Instituicao instituicao : instituicoes){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, usuario.getId());
                stmt.setLong(2, instituicao.getId());
                stmt.execute();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        }
    }
    
/* ------------------------------ SENHA CRIPTOGRAFADA ----------------------- */
    
    private String senhaCriptografada(Usuario usuario){
        return new MD5().encripta(usuario.getSenha());
    }
    
/* ------------------------------- REMOVER ---------------------------------- */
    
    
    public void remove(Usuario usuario){
        String sqlInstituicoes = "DELETE FROM item_usuario_instituicao WHERE id_usuario = ?";
        String sqlUsuario = "DELETE FROM usuario WHERE email = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sqlInstituicoes)){
                stmt.setLong(1, usuario.getId());
                stmt.execute();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
            try (PreparedStatement stmt = con.prepareStatement(sqlUsuario)){
                stmt.setString(1, usuario.getEmail());
                stmt.execute();
                con.commit();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* ---------------------------  REMOVE INSTITUICAO -------------------------- */
    
    public void removeInstituicao(Usuario usuario , Instituicao instituicao){
        String sql = "DELETE FROM item_usuario_instituicao WHERE id_usuario = ? AND id_instituicao = ?;";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, usuario.getId());
                stmt.setLong(2, instituicao.getId());
                stmt.execute();
                con.commit();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* -------------------------------- ATIVA ----------------------------------- */
    
    public Usuario ativa(Usuario usuario){
        String sql = "UPDATE usuario SET tipo = 1, ativo = true WHERE email = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setString(1, usuario.getEmail());
                stmt.execute();
                con.commit();
                return usuario;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
    public Usuario ativaInat(Usuario usuario){
        String sql = "UPDATE usuario SET ativo = true WHERE email = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setString(1, usuario.getEmail());
                stmt.execute();
                con.commit();
                return usuario;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* ------------------------------- DESATIVA --------------------------------- */
    
    public Usuario desativa(Usuario usuario){
        String sql = "UPDATE usuario SET ativo = false WHERE email = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setString(1, usuario.getEmail());
                stmt.execute();
                con.commit();
                usuario.setAtivo(false);
                return usuario;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* -------------------------------- PEGA ------------------------------------ */
    
    public Usuario pega(Usuario usuarioPesquisa){
        String sql = "SELECT id , nome , sobrenome , senha , tipo , ativo FROM usuario WHERE email = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setString(1, usuarioPesquisa.getEmail());
                try (ResultSet rs = stmt.executeQuery()){
                    if(rs.next()){
                        Usuario usuario = new Usuario();
                        usuario.setId(rs.getInt("id"));
                        usuario.setNome(rs.getString("nome"));
                        usuario.setSobrenome(rs.getString("sobrenome"));
                        usuario.setEmail(usuarioPesquisa.getEmail());
                        usuario.setSenha(rs.getString("senha"));
                        TipoUsuario tipoUsuario = new TipoUsuario();
                        tipoUsuario.setId(rs.getInt("tipo"));
                        usuario.setTipoUsuario(tipoUsuario);
                        usuario.setAtivo(rs.getBoolean("ativo"));
                        usuario.setInstituicoes(pegaInstituicoes(con, usuario));
                        return usuario;
                    }
                    throw new RuntimeException();
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* ---------------------------- PEGA INSTITUICOES --------------------------- */
    
    public List<Instituicao> pegaInstituicoes(Connection con , Usuario usuario){
        String sql = "SELECT instituicao.id, instituicao.nome FROM instituicao "
                + "inner join item_usuario_instituicao "
                + "on item_usuario_instituicao.id_instituicao = instituicao.id "
                + "WHERE item_usuario_instituicao.id_usuario = ?;";
        try (PreparedStatement stmt = con.prepareStatement(sql)){
            stmt.setLong(1, usuario.getId());
            try (ResultSet rs = stmt.executeQuery()){
                List<Instituicao> lista = new ArrayList<>();
                while(rs.next()){
                    Instituicao inst = new Instituicao();
                    inst.setId(rs.getInt("id"));
                    inst.setNome(rs.getString("nome"));
                    lista.add(inst);
                }
                return lista;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* ------------------------------- EDITA ------------------------------------ */
    
    public Usuario edita(Usuario usuarioEditado){
        String sql = "UPDATE usuario SET senha = ?  WHERE email = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setString(1, senhaCriptografada(usuarioEditado));
                stmt.setString(2, usuarioEditado.getEmail());
                stmt.execute();
                con.commit();
                return usuarioEditado;
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }   
    
/* ----------------------------- VINCULAR PROJETO --------------------------- */
    
    public void vincularProjeto(Usuario usuario , Projeto projeto){
        String sql = "INSERT INTO item_usuario_projeto ( id_usuario , id_projeto, tipo) VALUES ( ? , ?,0)";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, usuario.getId());
                stmt.setLong(2, projeto.getId());
                stmt.execute();
                con.commit();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
    public void solicitarVinculoProjeto(Usuario usuario , Projeto projeto){
        String sql = "INSERT INTO item_usuario_projeto ( id_usuario , id_projeto, tipo) VALUES (? , ? , ?,0)";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(2, usuario.getId());
                stmt.setLong(3, projeto.getId());
                stmt.execute();
                con.commit();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
/* --------------------------- DESVINCULAR PTOJETO -------------------------- */
    
    public void desvincularProjeto(Usuario usuario , Projeto projeto){
        String sql = "DELETE FROM item_usuario_projeto WHERE id_usuario = ? AND id_projeto = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            con.setAutoCommit(false);
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setLong(1, usuario.getId());
                stmt.setLong(2, projeto.getId());
                stmt.execute();
                con.commit();
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }
    
    
    public Usuario consulta(String email, String senha){
        String sql = "SELECT id , nome , sobrenome , senha , tipo, ativo FROM usuario WHERE email = ? and senha = ?";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setString(1, email);
                stmt.setString(2, new MD5().encripta(senha));
                try (ResultSet rs = stmt.executeQuery()){
                    if(rs.next()){
                        Usuario usuario = new Usuario();
                        usuario.setId(rs.getInt("id"));
                        usuario.setNome(rs.getString("nome"));
                        usuario.setSobrenome(rs.getString("sobrenome"));
                        usuario.setEmail(email);
                        usuario.setSenha(rs.getString("senha"));
                        TipoUsuario tipoUsuario = new TipoUsuario();
                        tipoUsuario.setId(rs.getInt("tipo"));
                        usuario.setAtivo(rs.getBoolean("ativo"));
                        usuario.setTipoUsuario(tipoUsuario);
                        usuario.setInstituicoes(pegaInstituicoes(con, usuario));
                        return usuario;
                    }else{
                        return null;
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }    
     public int consultaEmail(String email){
        String sql = "SELECT id FROM usuario WHERE email = ? ";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                stmt.setString(1, email);
                try (ResultSet rs = stmt.executeQuery()){
                    if(rs.next()){
                      return 1;
                    }else{
                        return 0;
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException();
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }    
     public List<Usuario> listaUsuariosInvalidos(){
          String sql = "SELECT id, nome, sobrenome,email FROM usuario where tipo = 0";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                try (ResultSet rs = stmt.executeQuery()){
                    List<Usuario> lista = new ArrayList<>();
                    while(rs.next()){
                        Usuario user = new Usuario();
                        user.setId((long)rs.getInt("id"));
                        user.setNome(rs.getString("nome"));
                        user.setSobrenome(rs.getString("sobrenome"));
                        user.setEmail(rs.getString("email"));
                        user.setInstituicoes(pegaInstituicoes(con, user));
                        lista.add(user);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
      public List<Usuario> listaUsuariosValidos(){
          String sql = "SELECT id, nome, sobrenome,email,tipo,ativo FROM usuario where tipo != 0";
        try (Connection con = new ConnectionFactory().getConnection()){
            try (PreparedStatement stmt = con.prepareStatement(sql)){
                try (ResultSet rs = stmt.executeQuery()){
                    List<Usuario> lista = new ArrayList<>();
                    while(rs.next()){
                        Usuario user = new Usuario();
                        user.setId((long)rs.getInt("id"));
                        user.setNome(rs.getString("nome"));
                        user.setSobrenome(rs.getString("sobrenome"));
                        user.setEmail(rs.getString("email"));
                        user.setInstituicoes(pegaInstituicoes(con, user));
                        TipoUsuario tipo = new TipoUsuario();
                        tipo.setId(rs.getInt("tipo"));
                        user.setTipoUsuario(tipo);
                        if(tipo.getId() == 1){
                            user.setSituacao("Usuário");
                            user.setCorS("green");
                        }else if(tipo.getId() == 2){
                            user.setSituacao("Administrador");
                            user.setCorS("blue");
                        }
                        user.setMostraU(rs.getBoolean("ativo"));
                        lista.add(user);
                    }
                    return lista;
                } catch (Exception e) {
                    e.printStackTrace();
                    throw new RuntimeException("Erro ao gerar a lista");
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new RuntimeException("Erro ao preparar o statement");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Erro ao conectar");
        }
     }
}
