package web.utilidades;


import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

import javax.faces.application.FacesMessage;
import javax.faces.bean.RequestScoped;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.ConverterException;
import javax.faces.convert.FacesConverter;

import org.apache.commons.codec.binary.Base64;

/**
 * 
 * 
 * Classe de Conversï¿½o de entidade.
 * 
 * Realiza a conversï¿½o de entidade de forma genï¿½rica: Bean --> interface, interface --> Bean.
 * Evita a criaï¿½ï¿½o e a manutenï¿½ï¿½o de converter para cada entidade individualmente.
 *
 *    ###    ##     ## ####  ######   #######  
 *   ## ##   ##     ##  ##  ##    ## ##     ## 
 *  ##   ##  ##     ##  ##  ##       ##     ## 
 * ##     ## ##     ##  ##   ######  ##     ## 
 * #########  ##   ##   ##        ## ##     ## 
 * ##     ##   ## ##    ##  ##    ## ##     ## 
 * ##     ##    ###    ####  ######   #######  
 *
 * Deve-se utilizar com cautela em entidades complexas ou em quantidades grandes de conversï¿½es. 
 * Pode acarretar em problemas de performance.
 *
 */
@RequestScoped
@FacesConverter(value="converterGenerico")
public class ConverterGenerico implements Converter {

	@Override
	public Object getAsObject(FacesContext arg0, UIComponent arg1, String arg2) {
		try {
			Base64 base64 = new Base64();
			@SuppressWarnings("static-access")
			byte[] objeto = base64.decodeBase64(arg2);
			ObjectInputStream in = new ObjectInputStream(
					new ByteArrayInputStream(objeto));
			return in.readObject();
		} catch (Exception e) {
			FacesMessage facesMessage = new FacesMessage(
					FacesMessage.SEVERITY_ERROR,
					"Falha ao converter a entidade: "
							+ arg2.getClass().getName() + " para o bean. Erro: "
							+ e.getMessage(), "");
                        e.printStackTrace();
			throw new ConverterException(facesMessage);
		}
	}

	@SuppressWarnings("static-access")
	@Override
	public String getAsString(FacesContext arg0, UIComponent arg1, Object arg2) {
		try {
			ByteArrayOutputStream bos = new ByteArrayOutputStream();
			ObjectOutputStream out = new ObjectOutputStream(bos);
			out.writeObject(arg2);
			Base64 base64 = new Base64();
			return base64.encodeBase64String(bos.toByteArray());
		} catch (Exception e) {
			FacesMessage facesMessage = new FacesMessage(
					FacesMessage.SEVERITY_ERROR,
					"Falha ao converter a entidade: "
							+ arg2.getClass().getName()
							+ " para a interface. Erro: " + e.getMessage(), "");
			throw new ConverterException(facesMessage);
		}
	}

}
