/* script que recria o banco */

drop table item_usuario_instituicao cascade;
drop table usuario cascade;
drop table tipo_usuario cascade;
drop table item_projeto_instituicao cascade;
drop table item_usuario_projeto cascade;
drop table projeto cascade;
drop table instituicao cascade;
drop table parte_do_corpo cascade;
drop table paciente cascade;
drop table tipo_exame cascade;
drop table exame cascade;
drop table imagem_original cascade;
drop table imagem_segmentada cascade;

/* script que recria o banco de desenvolvimento *

delete from item_usuario_instituicao;
delete from usuario;
delete from tipo_usuario;
delete from item_projeto_instituicao;
delete from item_usuario_projeto;
delete from projeto;
delete from instituicao;
delete from parte_do_corpo;
delete from paciente;
delete from tipo_exame;
delete from exame;
delete from imagem_original;
delete from imagem_segmentada;

/* TIPO_USUARIO */

create table if not exists  tipo_usuario (
  id serial ,
  tipo varchar (255) unique not null ,
  constraint pk_tipo_usuario primary key (id)
);

/* USUARIO */

create table if not exists usuario (
  id serial ,
  nome varchar (255) not null ,
  sobrenome varchar (255) not null ,
  email varchar (255) unique not null ,
  senha varchar (255) not null ,
  tipo int default 1 ,
  ativo boolean default true ,
  constraint pk_usuario primary key (id) ,
  constraint fk_tipo_usuario foreign key (tipo) references tipo_usuario (id)
);

/* INSTITUICAO */

create table if not exists instituicao (
  id serial ,
  nome varchar (255) unique not null  ,
  constraint pk_instituicao primary key (id)
);

/* ITEM_USUARIO_INSTITUICAO */

create table if not exists item_usuario_instituicao (
  id_usuario int not null ,
  id_instituicao int not null ,
  constraint pk_item_usuario_instituicao primary key (id_usuario , id_instituicao) ,
  constraint fk_item_usuario_instituicao_usuario foreign key (id_usuario) references usuario (id) ,
  constraint fk_item_usuario_instituicao_instituicao foreign key (id_instituicao) references instituicao (id)
);

/* PROJETO */

create table if not exists projeto (
  id serial ,
  nome varchar (255) unique not null ,
  descricao text not null ,
  moderador int not null ,
  ativo boolean default true ,
  constraint pk_projeto primary key (id) ,
  constraint fk_projeto_usuario foreign key (moderador) references usuario (id)
);

/* ITEM_INSTITUICAO_PROJETO */

create table if not exists item_projeto_instituicao (
  id_projeto int not null ,
  id_instituicao int not null ,
  constraint pk_item_projeto_instituicao primary key (id_projeto , id_instituicao) ,
  constraint fk_item_projeto_instituicao_projeto foreign key (id_projeto) references projeto (id) ,
  constraint fk_item_projeto_instituicao_instituicao foreign key (id_instituicao) references instituicao (id)
);

/* ITEM_USUARIO_PROJETO */

create table if not exists item_usuario_projeto (
  data_solicitacao timestamp default CURRENT_TIMESTAMP ,
  data_respota timestamp default null ,
  id_usuario int not null ,
  id_projeto int not null ,
  eh_administrador boolean default false ,
  constraint pk_item_usuario_projeto primary key (id_usuario , id_projeto) ,
  constraint fk_item_usuario_projeto_usuario foreign key (id_usuario) references usuario (id) ,
  constraint fk_item_usuario_projeto_projeto foreign key (id_projeto) references projeto (id)
);

/* PARTE_DO_CORPO */

create table if not exists parte_do_corpo (
  id serial ,
  parte varchar (255) unique not null ,
  constraint pk_parte_do_corpo primary key (id)
);

/* PACIENTE */

create table if not exists paciente (
  id serial ,
  nome varchar (255) not null ,
  data_nasc date default null ,
  constraint pk_paciente primary key (id)
);

/* TIPO_EXAME */

create table if not exists tipo_exame(
  id serial ,
  tipo varchar (255) unique not null ,
  constraint pk_tipo_exame primary key (id)
);

/* EXAME */

create table if not exists exame (
  id serial ,
  usuario_upload int not null ,
  projeto int not null ,
  tipo_exame int not null ,
  parte_do_corpo int not null ,
  data_envio timestamp default CURRENT_TIMESTAMP ,
  paciente int not null ,
  quantidade_imagens int default 1 ,
  local_exame varchar (255) not null ,
  nome varchar (255) not null ,
  constraint pk_exame primary key (id) ,
  constraint fk_exame_usuario foreign key (usuario_upload) references usuario (id) ,
  constraint fk_exame_projeto foreign key (projeto) references projeto (id) ,
  constraint fk_exame_tipo_exame foreign key (tipo_exame) references tipo_exame (id) ,
  constraint fk_exame_parte_do_corpo foreign key (parte_do_corpo) references parte_do_corpo (id) ,
  constraint fk_exame_paciente foreign key (paciente) references paciente (id)
);

/* IMAGEM_ORIGINAL */

create table if not exists imagem_original (
  id serial ,
  exame int not null ,
  local_imagem varchar (255) unique not null ,
  local_png varchar (255) unique not null ,
  corte int default null ,
  constraint pk_imagem_original primary key (id) ,
  constraint fk_imagem_original_exame foreign key (exame) references exame (id)
);

/* IMAGEM_SEGMENTADA */

create table if not exists imagem_segmentada (
  id serial ,
  usuario int not null ,
  local_png varchar (255) unique not null ,
  local_imagem varchar (255) unique not null ,
  data_edicao timestamp default CURRENT_TIMESTAMP ,
  imagem_original int not null ,
  constraint pk_imagem_segmentada primary key (id) ,
  constraint fk_imagem_segmentada_imagem foreign key (imagem_original) references imagem_original (id)
);

/* FORUM */

create table if not exists forum(
  id serial not null ,
  conteudo text not null ,
  data_criac date not null ,
  autor integer not null ,
  constraint pk_forum primary key (id) ,
  constraint fk_forum_usuario foreign key (autor)
);

/* testes  */

--inserts tipo_usuario
insert into tipo_usuario (tipo) values ('usuario-comum');
insert into tipo_usuario (tipo) values ('administrador');

--inserts usuario
insert into usuario (nome , sobrenome , email , senha , tipo)values ('joao' , 'felipe' , 'joaofelipe1294@gmail.com' , '1234' , 1);
insert into usuario (nome , sobrenome , email , senha , tipo)values ('vinicius' , 'calegari' , 'v_calegari@gmail.com' , '1234' , 1);
insert into usuario (nome , sobrenome , email , senha , tipo)values ('caio' , 'oliveira' , 'caio@oliveira@hotmail.com' , '4321' , 1);
insert into usuario (nome , sobrenome , email , senha , tipo)values ('andre' , 'silva' , 'andre_silva@gmail.com' , '159753' , 1);
insert into usuario (nome , sobrenome , email , senha , tipo)values ('anderson' , 'silva' , 'anderson@silva.com' , 'spider' , 1);
insert into usuario (nome , sobrenome , email , senha , tipo)values ('jose' , 'aldo junior' , 'aldo_king@hotmail.com' , 'aldo_rules' , 1);
insert into usuario (nome , sobrenome , email , senha , tipo)values ('vitor' , 'belfort' , 'vitor@belfort.com' , 'phenom' , 2);
insert into usuario (nome , sobrenome , email , senha , tipo)values ('daniel' , 'cormier' , 'dc@aka.com' , 'dc' , 2);
insert into usuario (nome , sobrenome , email , senha , tipo)values ('dana' , 'white' , 'dana@ufc.com' , 'ufc' , 2);

--inserts instituicao
insert into instituicao (nome) values ('UFPR');
insert into instituicao (nome) values ('PUC-PR');
insert into instituicao (nome) values ('TUIUTI');
insert into instituicao (nome) values ('UP');
insert into instituicao (nome) values ('UFMG');
insert into instituicao (nome) values ('UFSC');
insert into instituicao (nome) values ('PUC-RJ');
insert into instituicao (nome) values ('PUC-BAHIA');
insert into instituicao (nome) values ('MIT');
insert into instituicao (nome) values ('CEFET');

--inserts item_usuario_instituicao
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (1 , 1);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (1 , 2);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (1 , 4);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (2 , 1);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (5 , 3);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (1 , 7);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (3 , 3);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (4 , 4);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (4 , 2);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (4 , 5);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (2 , 5);
insert into item_usuario_instituicao (id_usuario , id_instituicao) values (5 , 2);

--inserts projeto
insert into projeto (nome , descricao , moderador) values ('Cura do cancer' , 'Projeto que visa a cura do cance' , 2);
insert into projeto (nome , descricao , moderador) values ('Estudo cancer pulmao' , 'Estudo dos tipos de cancer de pulmao' , 1);
insert into projeto (nome , descricao , moderador) values ('Cancer de prostata' , 'Estudo de desenvolvimento de casos de cancer de prostata' , 3);
insert into projeto (nome , descricao , moderador) values ('Relacao de fumo com cancer de faringe' , 'Estuda a co-relacao do tempo de fumo com cancer de faringe' , 4);
insert into projeto (nome , descricao , moderador) values ('Estudo do ABC' , 'toda crianca tem que ler e escrever by pele ou edson , nao sei ' , 2);
insert into projeto (nome , descricao , moderador) values ('T-virus' , 'umbrella corp is developing an virus that reanimates human tissues after the stop of brain activitys' , 1);
insert into projeto (nome , descricao , moderador) values ('G-Virus' , 'Dr Willian Birkin is finishing his study of an variable os T-virus that is more agressive than original virus' , 5);
insert into projeto (nome , descricao , moderador) values ('Salve o corinthians' , 'O campeao dos campeoes ' , 1);
insert into projeto (nome , descricao , moderador) values ('Coxa lider' , '#naoehlider' , 4);

--inserts item_projeto_instituicao
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (1 , 1);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (1 , 3);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (1 , 5);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (1 , 7);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (2 , 1);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (3 , 2);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (3 , 3);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (4 , 6);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (6 , 1);
insert into item_projeto_instituicao (id_projeto , id_instituicao) values (6 , 6);

--insserts item_usuario_projeto
insert into item_usuario_projeto (id_usuario , id_projeto) values (1 , 1);
insert into item_usuario_projeto (id_usuario , id_projeto) values (1 , 2);
insert into item_usuario_projeto (id_usuario , id_projeto) values (1 , 3);
insert into item_usuario_projeto (id_usuario , id_projeto) values (1 , 4);
insert into item_usuario_projeto (id_usuario , id_projeto) values (1 , 7);
insert into item_usuario_projeto (id_usuario , id_projeto) values (2 , 1);
insert into item_usuario_projeto (id_usuario , id_projeto) values (2 , 2);
insert into item_usuario_projeto (id_usuario , id_projeto) values (3 , 3);
insert into item_usuario_projeto (id_usuario , id_projeto) values (2 , 4);
insert into item_usuario_projeto (id_usuario , id_projeto) values (4 , 1);
insert into item_usuario_projeto (id_usuario , id_projeto) values (5 , 1);
insert into item_usuario_projeto (id_usuario , id_projeto) values (6 , 1);
insert into item_usuario_projeto (id_usuario , id_projeto) values (6 , 6);

--inserts parte_do_corpo
insert into parte_do_corpo (parte) values ('pé');
insert into parte_do_corpo (parte) values ('mão');
insert into parte_do_corpo (parte) values ('seio');
insert into parte_do_corpo (parte) values ('coxa');
insert into parte_do_corpo (parte) values ('cabeça');
insert into parte_do_corpo (parte) values ('ombro');
insert into parte_do_corpo (parte) values ('nádega');
insert into parte_do_corpo (parte) values ('torso');
insert into parte_do_corpo (parte) values ('joelho');
insert into parte_do_corpo (parte) values ('calcanhar');
insert into parte_do_corpo (parte) values ('punho');

--paciente
insert into paciente (nome , data_nasc) values ('bruno lopes' , '1993-01-21');
insert into paciente (nome , data_nasc) values ('tite' , '1988-12-20');
insert into paciente (nome , data_nasc) values ('murici ramalho' , '1940-07-12');
insert into paciente (nome , data_nasc) values ('luxemburgo' , '1959-09-21');
insert into paciente (nome , data_nasc) values ('dedé pederneiras' , '1997-06-30');
insert into paciente (nome , data_nasc) values ('greg jackson' , '1992-01-27');
insert into paciente (nome , data_nasc) values ('rafael cordeiro' , '2002-04-08');
insert into paciente (nome , data_nasc) values ('rogerio camoes' , '1967-11-09');
insert into paciente (nome , data_nasc) values ('urijah faber' , '1995-11-01');
insert into paciente (nome , data_nasc) values ('macaco patino' , '1998-12-10');
insert into paciente (nome , data_nasc) values ('charles do bronx' , '2000-07-18');
insert into paciente (nome , data_nasc) values ('max hollaway' , '1987-04-08');

--inserts tipo_exame
insert into tipo_exame (tipo) values ('tomografia');
insert into tipo_exame (tipo) values ('ultra-sonografia');
insert into tipo_exame (tipo) values ('raio-x');



insert into exame (usuario_upload , projeto , tipo_exame , parte_do_corpo , paciente , quantidade_imagens , local_exame , nome) values (1 , 1 , 1 , 1 , 1 , 50 , 'nessa/pasta' , 'exame kabulozzzzo');
insert into imagem_original (exame , local_imagem , local_png , corte) values (1 , 'imagens/imagem.dmc' , 'imagens/png/imagem.png' , 55);
insert into imagem_segmentada (usuario , local_png , local_imagem , data_edicao , imagem_original) values (1 , 'imagem_segmentada.png' , 'imagem-segmentada.dcm' , '2015-09-18' , 1);
