package dao;

import conexao.ConnectionFactory;
import java.util.List;
import modelos.Instituicao;
import modelos.Projeto;
import modelos.TipoUsuario;
import modelos.Usuario;
import org.junit.Test;
import static org.junit.Assert.*;
import org.junit.Before;

public class UsuarioDAOTest {
    private Usuario usuario;
    private TipoUsuario tipoUsuario;
    private UsuarioDAO dao;
    
    @Before
    public void init(){
        usuario = new Usuario();
        usuario.setNome("Steve");
        usuario.setSobrenome("Jobs");
        usuario.setEmail("steve@jobs.apple.com");
        usuario.setSenha("macbook");
        tipoUsuario = new TipoUsuario();
        tipoUsuario.setId(1);
        usuario.setTipoUsuario(tipoUsuario);
        dao = new UsuarioDAO();
    }
    
    @Test(expected = RuntimeException.class)
    public void cadastroNulo(){
        dao.cadastra(new Usuario());
    }
    
    @Test(expected = RuntimeException.class)
    public void cadastroDupicado(){
        Usuario usuarioDuplicado = new Usuario();
        usuarioDuplicado.setNome("Daniel");
        usuarioDuplicado.setSobrenome("Cormier");
        usuarioDuplicado.setEmail("daniel_dc@ufc.com");
        usuarioDuplicado.setSenha("akaacademy");
        TipoUsuario tipoUsuarioDuplicado = new TipoUsuario();
        tipoUsuarioDuplicado.setId(1);
        usuarioDuplicado.setTipoUsuario(tipoUsuarioDuplicado);
        try {
            dao.cadastra(usuarioDuplicado);
            dao.cadastra(usuarioDuplicado);
        } catch (Exception e) {
            dao.remove(usuarioDuplicado);
            throw new RuntimeException();
        }
    }
    
    @Test
    public void ativaUsuario(){
        assertEquals(true, dao.ativa(usuario).isAtivo());
    }
    
    @Test
    public void desativaUsuario(){
        assertEquals(false, dao.desativa(usuario).isAtivo());
    }
    
    @Test
    public void crud(){
        usuario = dao.cadastra(usuario);
        assertEquals(usuario, dao.pega(usuario));
        usuario.setNome("Ronaldo");
        usuario.setSobrenome("Arantes do Nascimento");
        Usuario usuarioEditado = dao.edita(usuario);
        assertEquals(usuarioEditado, usuario);
        dao.remove(usuario);
    }
    
    @Test 
    public void cadastraUsuarioComInstituicoes(){
        Usuario novoUsuario = new Usuario();
        novoUsuario.setNome("Phage");
        novoUsuario.setSobrenome("a Intocável");
        novoUsuario.setEmail("phage@cabala.magic.com");
        novoUsuario.setSenha("cabala");
        novoUsuario.setTipoUsuario(tipoUsuario);
        novoUsuario.adicionaInstituicao(new Instituicao(1));
        novoUsuario.adicionaInstituicao(new Instituicao(2));
        novoUsuario.adicionaInstituicao(new Instituicao(4));
        novoUsuario = dao.cadastra(novoUsuario);
        assertEquals(dao.pega(novoUsuario).getInstituicoes(), novoUsuario.getInstituicoes());
        List<Instituicao> lista = novoUsuario.getInstituicoes();
        lista.remove(2);
        dao.removeInstituicao(novoUsuario, new Instituicao(4));
        assertEquals(lista, dao.pegaInstituicoes(new ConnectionFactory().getConnection(), novoUsuario));
        dao.remove(novoUsuario);
    }
    
    @Test
    public void vinculaProjeto(){
        Projeto projeto = new Projeto();
        projeto.setId(6);
        Usuario usuarioProjeto = new Usuario();
        usuarioProjeto.setId(1);
        //dao.vincularProjeto(usuarioProjeto, projeto);
        dao.desvincularProjeto(usuarioProjeto, projeto);
    }
    
}
